==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/os/gos42.h <==
/****************************************************************************

  module      : gos42.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: socket communication
  description : description ...


  last changed: 1999-04-16  11:34
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GOS42_H
#define GOS42_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

tsp00_Longuint 
os42SocketSend    ( void                         *SendHandle,
                    void                         *pData,
                    int                           Len,
                    tsp00_ErrTextc VAR_ARRAY_REF  pErrText ) ;

tsp00_Longuint 
os42SocketReceive ( void                         *RecvHandle,
                    void                         *pData,
                    tsp00_Longuint                ulMaxDataLen,
                    tsp00_Longuint               *BytesReceived,
                    tsp00_ErrTextc VAR_ARRAY_REF  pErrText ) ;

tsp00_Longuint 
os42SocketSetBuf ( int                           SocketHandle,
                   tsp00_Longuint                MinBufSize,
                   tsp00_Longuint               *MaxBufSize,
                   tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GOS42_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/os/gos42.h <==
/****************************************************************************

  module      : gos42.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: socket communication
  description : description ...


  last changed: 1999-04-16  11:34
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GOS42_H
#define GOS42_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

tsp00_Uint     
os42SocketSend    ( void                         *SendHandle,
                    void                         *pData,
                    int                           Len,
                    tsp00_ErrTextc VAR_ARRAY_REF  pErrText ) ;

tsp00_Uint     
os42SocketReceive ( void                         *RecvHandle,
                    void                         *pData,
                    tsp00_Uint                    ulMaxDataLen,
                    tsp00_Uint                   *BytesReceived,
                    tsp00_ErrTextc VAR_ARRAY_REF  pErrText ) ;

tsp00_Uint     
os42SocketSetBuf ( teo00_Socket                  SocketHandle,
                   tsp00_Uint                    MinBufSize,
                   tsp00_Uint                   *MaxBufSize,
                   tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GOS42_H */
